# Big data

Результат, который выдал Claude на промпт

```plain
> Напиши на русском языке статью на тему "big data и machine learning". В статье раскрой следующие вопросы:
> 
> 1. Что такое big data и machine learning, каково назначение того и дургого
> 2. что у них общего в чем различия, как они связаны друг с другом
> 3. Какие технологии используются обычно для построения того и другого
> 
> Формат изложения:
> 
> 1. Статья должна быть разбита на разделы;
> 2. каждый раздел в отдельном файле Markdown в каталоге src;
> 3. имена файлов должны содержать порядковый номер и краткая суть раздела от одного до пяти слов на английском
> 4. Формат файлов Markdown должен соответствовать CommonMark Spec и без ошибок проходить валидацию при помощи markdownlint.
>    4.1. markdownlint установлен, как глобальная cli-утилита, для проверки всех файлов в каталоге src/ достаточно команды `markdownlint ./src/`
```
